==> jc-1.4.0.tar.gz: soot/tagkit/JasminAttribute.h <==
// public abstract class soot.tagkit.JasminAttribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 30cb4952e1c8862c soot_tagkit_JasminAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_JasminAttribute_H_
#define _JC_soot_tagkit_JasminAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_tagkit_JasminAttribute$sub_refs	_jc_soot_tagkit_JasminAttribute$sub_refs;
typedef struct _jc_soot_tagkit_JasminAttribute$sub_nonrefs	_jc_soot_tagkit_JasminAttribute$sub_nonrefs;
typedef struct _jc_soot_tagkit_JasminAttribute$refs	_jc_soot_tagkit_JasminAttribute$refs;
typedef struct _jc_soot_tagkit_JasminAttribute$nonrefs	_jc_soot_tagkit_JasminAttribute$nonrefs;
typedef struct _jc_soot_tagkit_JasminAttribute$object	_jc_soot_tagkit_JasminAttribute$object;

typedef const struct _jc_soot_tagkit_JasminAttribute$vmethods	_jc_soot_tagkit_JasminAttribute$vmethods;
typedef const struct _jc_soot_tagkit_JasminAttribute$vtable	_jc_soot_tagkit_JasminAttribute$vtable;
typedef const struct _jc_soot_tagkit_JasminAttribute$vtype	_jc_soot_tagkit_JasminAttribute$vtype;

// Constructors
extern void _jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *);

// Virtual methods
extern _jc_byte_array *_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59;
extern _jc_method _jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827;

// Virtual methods structure
struct _jc_soot_tagkit_JasminAttribute$vmethods {
	_jc_byte_array	*(*decode$842483d88e34cc59)(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *);
	struct _jc_java_lang_String$object	*(*getJasminValue$3e470c5e1d385827)(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_tagkit_JasminAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_JasminAttribute$vmethods	soot_tagkit_JasminAttribute;
};

// Vtype
struct _jc_soot_tagkit_JasminAttribute$vtype {
	_jc_type			type;
	_jc_soot_tagkit_JasminAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_JasminAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_JasminAttribute$refs {
    _jc_soot_tagkit_JasminAttribute$sub_refs	soot_tagkit_JasminAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_JasminAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_JasminAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_JasminAttribute$sub_nonrefs	soot_tagkit_JasminAttribute;
};

// Object instance structure
struct _jc_soot_tagkit_JasminAttribute$object {
	_jc_soot_tagkit_JasminAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_JasminAttribute$vtype	*vtype;
	_jc_soot_tagkit_JasminAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_JasminAttribute$vtype _jc_soot_tagkit_JasminAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_JasminAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_JasminAttribute$class_object;

#endif	/* _JC_soot_tagkit_JasminAttribute_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/JasminAttribute.h <==
// public abstract class soot.tagkit.JasminAttribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 30cb4952e1c8862c soot_tagkit_JasminAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_JasminAttribute_H_
#define _JC_soot_tagkit_JasminAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_tagkit_JasminAttribute$sub_refs	_jc_soot_tagkit_JasminAttribute$sub_refs;
typedef struct _jc_soot_tagkit_JasminAttribute$sub_nonrefs	_jc_soot_tagkit_JasminAttribute$sub_nonrefs;
typedef struct _jc_soot_tagkit_JasminAttribute$refs	_jc_soot_tagkit_JasminAttribute$refs;
typedef struct _jc_soot_tagkit_JasminAttribute$nonrefs	_jc_soot_tagkit_JasminAttribute$nonrefs;
typedef struct _jc_soot_tagkit_JasminAttribute$object	_jc_soot_tagkit_JasminAttribute$object;

typedef const struct _jc_soot_tagkit_JasminAttribute$vmethods	_jc_soot_tagkit_JasminAttribute$vmethods;
typedef const struct _jc_soot_tagkit_JasminAttribute$vtable	_jc_soot_tagkit_JasminAttribute$vtable;
typedef const struct _jc_soot_tagkit_JasminAttribute$vtype	_jc_soot_tagkit_JasminAttribute$vtype;

// Constructors
extern void _jc_soot_tagkit_JasminAttribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_soot_tagkit_JasminAttribute$method$decode$842483d88e34cc59(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_JasminAttribute$method$getJasminValue$3e470c5e1d385827(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_JasminAttribute$method_info$decode$842483d88e34cc59;
extern _jc_method _jc_soot_tagkit_JasminAttribute$method_info$getJasminValue$3e470c5e1d385827;

// Virtual methods structure
struct _jc_soot_tagkit_JasminAttribute$vmethods {
	_jc_byte_array	*(*decode$842483d88e34cc59)(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getJasminValue$3e470c5e1d385827)(_jc_env *, struct _jc_soot_tagkit_JasminAttribute$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_JasminAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_JasminAttribute$vmethods	soot_tagkit_JasminAttribute;
};

// Vtype
struct _jc_soot_tagkit_JasminAttribute$vtype {
	_jc_type			type;
	_jc_soot_tagkit_JasminAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_JasminAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_JasminAttribute$refs {
    _jc_soot_tagkit_JasminAttribute$sub_refs	soot_tagkit_JasminAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_JasminAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_JasminAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_JasminAttribute$sub_nonrefs	soot_tagkit_JasminAttribute;
};

// Object instance structure
struct _jc_soot_tagkit_JasminAttribute$object {
	_jc_soot_tagkit_JasminAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_JasminAttribute$vtype	*vtype;
	_jc_soot_tagkit_JasminAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_JasminAttribute$vtype _jc_soot_tagkit_JasminAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_JasminAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_JasminAttribute$class_object;

#endif	/* _JC_soot_tagkit_JasminAttribute_H_ */
